# Wahoo

What does it do

## Installation

# From source

	git clone XXX
	cd wahoo
	make install
	
# From pip

	mkdir wahoo
	cd wahoo
	virtualenv --python=/usr/bin/python3.6 venv   #Set up virtual environment using python 3.6
	source venv/bin/activate
	#pip install wahoo #not implemented yet!
	

## Running the tests

	make test
	

